<?php
//
// Copyright (c) 2008-2014 Nagios Enterprises, LLC.  All rights reserved.
//
// $Id: globalconfig.php 2811 2014-07-17 14:26:44Z jomann $

require_once(dirname(__FILE__) . '/../includes/common.inc.php');
require_once(dirname(__FILE__) . '/../includes/utils-timezones.inc.php');

// Initialization stuff
pre_init();
init_session();

// Grab GET or POST variables 
grab_request_vars();

// Check prereqs and authentication
check_prereqs();
check_authentication(false);

// Only admins can access this page
if (is_admin() == false) {
    echo $lstr['NotAuthorizedErrorText'];
    exit();
}

// Route request
route_request();

function route_request()
{
    global $request;
    if (isset($request['update'])) {
        do_update_options();
    } else {
        show_options();
    }
}

/**
 * @param bool   $error
 * @param string $msg
 */
function show_options($error = false, $msg = "")
{
    global $request;
    global $lstr;

    $url = get_option('url');
    if (have_value($url) == false) {
        $url = get_base_url();
    }

    // Get options
    $url = grab_request_var("url", $url);
    $external_url = grab_request_var("external_url", get_option('external_url'));
    $admin_name = grab_request_var("admin_name", get_option('admin_name'));
    $admin_email = grab_request_var("admin_email", get_option('admin_email'));
    $language = grab_request_var("defaultLanguage", get_option('default_language'));
    $date_format = grab_request_var("defaultDateFormat", get_option('default_date_format'));
    $number_format = grab_request_var("defaultNumberFormat", intval(get_option('default_number_format')));

    // System setting for new XI theme
    $theme = grab_request_var("theme", get_option('theme', 'xi2014'));
    $hc_theme = grab_request_var("hc_theme", get_option('default_highcharts_theme'));
    $perfdata_theme = grab_request_var("perfdata_theme", get_option('perfdata_theme'));

    // CCM auto-login integration
    //$separate_ccm_login = grab_request_var("separate_ccm_login", get_option('separate_ccm_login', 0));

    // Config Timezone
    $cfg_timezone = grab_request_var("timezone", get_option('timezone'));

    // If perfdata theme doesn't exist we should set it to 1
    if (get_option('perfdata_theme') == NULL) {
        $perfdata_theme = 1;
    }

    // Set defaults for admin name/email
    if ($admin_name == "") {
        $admin_name = "Nagios XI Admin";
    }
    if ($admin_email == "") {
        $admin_email = "root@localhost";
    }

    // Default to check for updates unless overridden
    $auc = get_option('auto_update_check');
    if ($auc == "") {
        $auc = 1;
    }
    $auto_update_check = grab_request_var("auto_update_check", $auc);
    if ($auto_update_check == "on") {
        $auto_update_check = 1;
    }

    // Allow html in status text?
    $allow_html = grab_request_var('allow_html', get_option('allow_status_html'));

    // Get global variables
    $languages = get_languages();
    $themes = get_themes();
    $number_formats = get_number_formats();
    $date_formats = get_date_formats();

    // Start actual "System Settings" page output
    do_page_start(array("page_title" => gettext("System Settings")), true);
    ?>

    <h1><?php echo gettext("System Settings"); ?></h1>
    <?php display_message($error, false, $msg); ?>
    <form id="manageOptionsForm" method="post" action="<?php echo encode_form_val($_SERVER['PHP_SELF']); ?>">
        <input type="hidden" name="options" value="1">
        <?php echo get_nagios_session_protector(); ?>
        <input type="hidden" name="update" value="1">

        <div class="sectionTitle"><?php echo gettext("General Program Settings"); ?></div>
        <table class="manageOptionsTable">
            <tr>
                <td valign="top">
                    <label for="urlBox"><?php echo gettext("Program URL"); ?>:</label>
                </td>
                <td style="padding-bottom: 6px;">
                    <input type="text" size="45" name="url" id="urlBox" value="<?php echo encode_form_val($url); ?>"
                           class="textfield">

                    <div><?php echo gettext("The default URL used to access Nagios XI directly from your internal network"); ?>
                        .
                    </div>
                </td>
            </tr>
            <tr>
                <td valign="top">
                    <label for="externalurlBox"><?php echo gettext("External URL"); ?>:</label>
                </td>
                <td style="padding-bottom: 6px;">
                    <input type="text" size="45" name="external_url" id="externalurlBox"
                           value="<?php echo encode_form_val($external_url); ?>" class="textfield"/>

                    <div><?php echo gettext("The URL used to access Nagios XI from outside of your internal network (if different than the default above).  If defined, this URL will be referenced in email alerts and generated pdf reports to allow quick access to the XI interface"); ?>
                        .
                    </div>
                </td>
            </tr>
            <tr>
                <td>
                    <label for="adminNameBox"><?php echo gettext("Administrator Name"); ?>:</label>
                </td>
                <td style="padding-bottom: 6px;">
                    <input type="text" size="30" name="admin_name" id="adminNameBox"
                           value="<?php echo encode_form_val($admin_name); ?>" class="textfield"/>
                </td>
            </tr>
            <tr>
                <td>
                    <label for="adminEmailBox"><?php echo gettext("Administrator Email Address"); ?>:</label>
                </td>
                <td style="padding-bottom: 6px;">
                    <input type="text" size="30" name="admin_email" id="adminEmailBox"
                           value="<?php echo encode_form_val($admin_email); ?>" class="textfield"/>
                </td>
            </tr>
            <tr>
                <td style="padding-bottom: 6px;">
                    <label for="autoUpdateCheckBox"><?php echo gettext("Automatically Check for Updates"); ?>:</label>

                    <div><a href="<?php echo get_update_check_url(); ?>"
                            target="_blank"><?php echo gettext("Check Now"); ?></a></div>
                </td>
                <td>
                    <input type="checkbox" class="checkbox" id="autoUpdateCheckBox"
                           name="auto_update_check" <?php echo is_checked($auto_update_check, 1); ?>>
                </td>
            </tr>
            <tr>
                <td>
                    <label for="allow_html"><?php echo gettext("Allow HTML Tags in Host/Service Status"); ?>:</label>
                </td>
                <td>
                    <input type="checkbox" id="allow_html" name="allow_html" <?php echo is_checked($allow_html); ?>>
                </td>
            </tr>
        </table>

        <?php
        /*
        <div class="sectionTitle"><?php echo gettext("CCM Integration Settings"); ?></div>
        <table class="manageOptionsTable">
            <tr>
                <td>
                    <label for="sccmlogin"><?php echo gettext("Separate CCM Login"); ?>:</label>
                </td>
                <td>
                    <input type="checkbox" name="separate_ccm_login" id="sccmlogin"
                           value="1" <?php echo is_checked($separate_ccm_login, 1); ?>>

                    <div><?php echo gettext("Revert back to the old way the CCM authenticated users"); ?></div>
                </td>
            </tr>
        </table>
        */
        ?>

        <!-- New 2014 XI Theme Setting & Timezone Settings -->
        <?php
        if (use_2014_features()) {
            $current_timezone = get_current_timezone();
            if (!empty($cfg_timezone) && $cfg_timezone != $current_timezone) {
                $current_timezone = $cfg_timezone;
            }
            $timezones = get_timezones();
            ?>

            <div class="sectionTitle"><?php echo gettext("Timezone Settings"); ?></div>
            <table class="manageOptionsTable">
                <tr>
                    <td><label><?php echo gettext("Timezone"); ?>:</label></td>
                    <td>
                        <select id="timezone" name="timezone">
                            <?php
                            $set = false;
                            foreach ($timezones as $name => $tz) {
                                ?>
                                <option value="<?php echo $tz; ?>"<?php if ($tz == $current_timezone) {
                                    echo "selected";
                                    $set = true;
                                } ?>><?php echo $name; ?></option>
                            <?php
                            }

                            if (!$set) {
                                ?>
                                <option value="<?php echo $current_timezone; ?>"
                                        selected><?php echo $current_timezone; ?></option>
                            <?php
                            }
                            ?>
                        </select>
                    </td>
                </tr>
            </table>

            <div class="sectionTitle"><?php echo gettext("Default Display/Theme Settings"); ?></div>
            <table class="manageOptionsTable">
                <tr>
                    <td><label><?php echo gettext("XI User Interface Theme"); ?>:</label></td>
                    <td style="padding-bottom: 6px;">
                        <select id="theme" name="theme">
                            <option value="classic"<?php if ($theme == 'classic') {
                                echo " selected";
                            } ?>><?php echo gettext("Classic XI"); ?></option>
                            <option value="xi2014"<?php if ($theme == 'xi2014') {
                                echo " selected";
                            } ?>><?php echo gettext("XI 2014"); ?></option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <td><label><?php echo gettext("Highcharts Color Theme"); ?>:</label></td>
                    <td style="padding-bottom: 6px;">
                        <select id="hc_theme" name="hc_theme">
                            <option value="default"<?php if ($hc_theme == 'default') {
                                echo " selected";
                            } ?>><?php echo gettext("Default (White)"); ?></option>
                            <option value="gray"<?php if ($hc_theme == 'gray') {
                                echo " selected";
                            } ?>><?php echo gettext("Classic (Gray)"); ?></option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <td><label><?php echo gettext("Use Highcharts for Perfdata Graphs"); ?>:</label></td>
                    <td>
                        <input type="checkbox" class="checkbox" id="perfdataThemeCheckBox" name="perfdata_theme"
                               value="1" <?php echo is_checked($perfdata_theme, 1); ?> />
                    </td>
                </tr>
            </table>

        <?php } // End 2014 features section ?>

        <div class="sectionTitle"><?php echo gettext("Default User Settings"); ?></div>
        <table class="manageOptionsTable">
            <tr>
                <td>
                    <label for="defaultLanguage"><?php echo gettext("Language"); ?>:</label>
                </td>
                <td style="padding-bottom: 6px;">
                    <select name="defaultLanguage" class="languageList dropdown">
                        <?php
                        foreach ($languages as $lang => $title) {
                            echo '<option value="' . $lang . '" ' . is_selected($language, $lang) . '>' . get_language_nicename($title) . '</option>';
                        }
                        ?>
                    </select>
                </td>
            </tr>
            <tr>
                <td>
                    <label for="defaultDateFormat"><?php echo gettext("Date Format"); ?>:</label>
                </td>
                <td style="padding-bottom: 6px;">
                    <select name="defaultDateFormat" class="dateformatList dropdown">
                        <?php
                        foreach ($date_formats as $id => $txt) {
                            echo '<option value="' . $id . '" ' . is_selected($id, $date_format) . '>' . $txt . '</option>';
                        }
                        ?>
                    </select>
                </td>
            </tr>
            <tr>
                <td>
                    <label for="defaultNumberFormat"><?php echo gettext("Number Format"); ?>:</label>
                </td>
                <td>
                    <select name="defaultNumberFormat" class="numberformatList dropdown">
                        <?php
                        foreach ($number_formats as $id => $txt) {
                            echo '<option value="' . $id . '" ' . is_selected($id, $number_format) . '>' . $txt . '</option>';
                        }
                        ?>
                    </select>
                </td>
            </tr>
        </table>
        <div id="formButtons" style="margin-top: 15px;">
            <input type="submit" class="submitbutton" name="updateButton"
                   value="<?php echo gettext("Update Settings"); ?>" id="updateButton">
            <input type="submit" class="submitbutton" name="cancelButton" value="<?php echo gettext("Cancel"); ?>"
                   id="cancelButton">
        </div>
    </form>
    <?php
    do_page_end(true);
}

// Save the options we just set with the above form
function do_update_options()
{
    global $request;
    global $lstr;

    // User pressed the cancel button
    if (isset($request["cancelButton"])) {
        header("Location: main.php");
    }

    // Check session
    check_nagios_session_protector();

    $errmsg = array();
    $errors = 0;

    // Get values
    $auto_update_check = grab_request_var("auto_update_check", "");
    $auto_update_check = ((have_value($auto_update_check)) ? 1 : 0);
    $admin_name = grab_request_var("admin_name", "");
    $admin_email = grab_request_var("admin_email", "");
    $url = grab_request_var("url", "");
    $external_url = grab_request_var("external_url", "");
    $date_format = grab_request_var("defaultDateFormat", DF_ISO8601);
    $number_format = grab_request_var("defaultNumberFormat", NF_2);
    $language = grab_request_var("defaultLanguage", "");
    $allow_html = grab_request_var('allow_html', false);

    // Theme settings for 2014
    $theme = grab_request_var("theme", "");
    $hc_theme = grab_request_var("hc_theme", "");
    $perfdata_theme = grab_request_var("perfdata_theme", 0);

    // Grab the CCM auto-login integration
    //$separate_ccm_login = grab_request_var("separate_ccm_login", 0);

    // Get the timezone
    $new_timezone = grab_request_var("timezone", "");

    // Make sure we have requirements
    if (in_demo_mode() == true)
        $errmsg[$errors++] = $lstr['DemoModeChangeError'];
    if (have_value($admin_name) == false)
        $errmsg[$errors++] = $lstr["NoAdminNameError"];
    if (have_value($admin_email) == false)
        $errmsg[$errors++] = $lstr["NoAdminEmailError"];
    else if (!valid_email($admin_email))
        $errmsg[$errors++] = $lstr["InvalidAdminEmailError"];
    if (have_value($url) == false)
        $errmsg[$errors++] = $lstr['BlankURLError'];
    else if (!valid_url($url))
        $errmsg[$errors++] = $lstr['InvalidURLError'];
    if (have_value($language) == false)
        $errmsg[$errors++] = $lstr['BlankDefaultLanguageError'];

    // Handle errors
    if ($errors > 0) {
        show_options(true, $errmsg);
    }

    // Update options
    set_option("admin_name", $admin_name);
    set_option("admin_email", $admin_email);
    set_option("url", $url);
    set_option("external_url", $external_url);
    set_option("default_language", $language);
    set_language($language);
    set_option("auto_update_check", $auto_update_check);
    set_option("default_date_format", $date_format);
    set_option("default_number_format", $number_format);
    set_option('allow_status_html', $allow_html);

    // Set theme options for 2014 
    set_option("theme", $theme);
    set_option("default_highcharts_theme", $hc_theme);
    set_option("perfdata_theme", $perfdata_theme);

    // Set new CCM integration option
    set_option("separate_ccm_login", $separate_ccm_login);

    // Set the timezone (so we can update it when page reloads)
    set_option("timezone", $new_timezone);

    // Mark that system settings were configured
    set_option("system_settings_configured", 1);

    // Log it
    send_to_audit_log("User updated global program settings", AUDITLOGTYPE_CHANGE);

    // Update the timezone if we need to!
    $current_timezone = get_current_timezone();
    if (!empty($new_timezone) && $current_timezone != $new_timezone) {
        submit_command(COMMAND_CHANGE_TIMEZONE, $new_timezone);
    }

    show_options(false, $lstr['GlobalConfigUpdatedText']);
}

function draw_menu()
{
    // Not sure what this does?
}